Index: /trunk/tools/geometry_tools.py
===================================================================
--- /trunk/tools/geometry_tools.py	(revision 2562)
+++ /trunk/tools/geometry_tools.py	(revision 2563)
@@ -609,8 +609,4 @@
         print errormsg
         print '  ' + fname + ': no cutting for polygon at y=', yval, '!!'
-
-    print 'Lluis icut', icut, 'ipt:', ipt, 'ecut', ecut, 'ept:', ept, 'N', N
-    print 'Lluis 00', polygon[0:7,:]
-    print 'Lluis NN', polygon[ecut+1:N,:]
 
     if keep == 'left':
@@ -1516,5 +1512,5 @@
     return island1, islandsecs, islanddic
 
-def buoy1(height=5., width=10., bradii=1.75, bfrac=0.8, N=200):
+def buoy1(height=5., width=10., bradii=1.75, bfrac=0.8, N=300):
     """ Function to draw a buoy as superposition of prism and section of ball
       height: height of the prism (5., default) 
@@ -1522,5 +1518,5 @@
       bradii: radii of the ball (1.75, default)
       bfrac: fraction of the ball above the prism (0.8, default)
       N: total number of points of the buoy (200, default)
     """
     fname = 'buoy1'
@@ -1528,21 +1524,11 @@
     buoy = np.zeros((N,2), dtype=np.float)
 
+    N3 = int(N/3/5)
     NNp = 0
     iip = 0
-    # Base
-    ix = width/2.
-    iy = 0.
-    Np = 4
-    dx = -width/(Np-1)
-    dy = 0.
-    for ip in range(Np):
-        buoy[iip+ip,:] = [iy+dy*ip,ix+dx*ip]
-    NNp = NNp + Np
-    iip = NNp
-
     # left lateral
     ix = -width/2.
+    Np = N3
     iy = 0.
-    Np = 2
     dx = 0.
     dy = height/(Np-1)
@@ -1555,5 +1541,4 @@
     ix = -width/2.
     iy = height
-    Np = 4
     dx = (width/2.-bradii*bfrac)/(Np-1)
     dy = 0.
@@ -1566,5 +1551,5 @@
     p1 = np.array([height, -bradii*bfrac])
     p2 = np.array([height, bradii*bfrac])
-    Np = N - 2*(NNp)
+    Np = int(2*N/3)
     buoy[iip:iip+Np,:] = circ_sec(p1, p2, 2.*bradii, 'long', 'left', Np)
     NNp = NNp + Np
@@ -1574,5 +1559,5 @@
     ix = bradii*bfrac
     iy = height
-    Np = 4
+    Np = N3
     dx = (width/2.-bradii*bfrac)/(Np-1)
     dy = 0.
@@ -1585,7 +1570,17 @@
     ix = width/2.
     iy = height
-    Np = 2
     dx = 0.
     dy = -height/(Np-1)
+    for ip in range(Np):
+        buoy[iip+ip,:] = [iy+dy*ip,ix+dx*ip]
+    NNp = NNp + Np
+    iip = NNp
+
+    # Base
+    ix = width/2.
+    iy = 0.
+    Np = N - int(2*N/3) - 4*N3
+    dx = -width/(Np-1)
+    dy = 0.
     for ip in range(Np):
         buoy[iip+ip,:] = [iy+dy*ip,ix+dx*ip]
@@ -1522,5 +1518,5 @@
       bradii: radii of the ball (1.75, default)
       bfrac: fraction of the ball above the prism (0.8, default)
-      N: total number of points of the buoy (200, default)
+      N: total number of points of the buoy (300, default)
     """
     fname = 'buoy1'
